]> git.mxchange.org Git - friendica.git/commitdiff
Move DB_UPDATE_VERSION from boot.php to config/dbstructure.php
authorHypolite Petovan <hypolite@mrpetovan.com>
Sun, 21 Oct 2018 05:58:10 +0000 (01:58 -0400)
committerHypolite Petovan <hypolite@mrpetovan.com>
Mon, 22 Oct 2018 20:50:55 +0000 (16:50 -0400)
boot.php
config/dbstructure.php
src/App.php
src/Database/DBStructure.php
update.php

index a1154cf75691c676414210ef7178a054de9da17f..7fb87ca4eb4391d9c5086c7eefdcf0b2e105b7a1 100644 (file)
--- a/boot.php
+++ b/boot.php
@@ -41,7 +41,6 @@ define('FRIENDICA_PLATFORM',     'Friendica');
 define('FRIENDICA_CODENAME',     'The Tazmans Flax-lily');
 define('FRIENDICA_VERSION',      '2018.12-dev');
 define('DFRN_PROTOCOL_VERSION',  '2.23');
-define('DB_UPDATE_VERSION',      1289);
 define('NEW_UPDATE_ROUTINE_VERSION', 1170);
 
 /**
index 7a96c0077fb67a2c2a2a1eba4e22b0535f3b9a6b..96f90fb8243b473381afd94ef4e7aff8dd812fee 100644 (file)
  *     ],
  * ],
  *
+ * If you need to make any change, make sure to increment the DB_UPDATE_VERSION constant value below.
  *
  */
 
 use Friendica\Database\DBA;
 
+if (!defined('DB_UPDATE_VERSION')) {
+       define('DB_UPDATE_VERSION', 1289);
+}
+
 return [
        "addon" => [
                "comment" => "registered addons",
index d8d6439d7276aa03236b68ec2c00a6dfeea1349b..6ec61db724c4b136b1f85ed109f1f4884d17af5b 100644 (file)
@@ -573,7 +573,11 @@ class App
 
                $stamp1 = microtime(true);
 
-               DBA::connect($db_host, $db_user, $db_pass, $db_data, $charset);
+               if (DBA::connect($db_host, $db_user, $db_pass, $db_data, $charset)) {
+                       // Loads DB_UPDATE_VERSION constant
+                       Database\DBStructure::definition();
+               }
+
                unset($db_host, $db_user, $db_pass, $db_data, $charset);
 
                $this->saveTimestamp($stamp1, 'network');
index 4e4c69b1d8bafe9ec0e6864e122271b51bf1ba70..f9335da8edb7e08640a8f0567571a75aaeaae5c2 100644 (file)
@@ -5,8 +5,8 @@
 namespace Friendica\Database;
 
 use Exception;
-use Friendica\Core\Hook;
 use Friendica\Core\Config;
+use Friendica\Core\Hook;
 use Friendica\Core\L10n;
 use Friendica\Util\DateTimeFormat;
 
@@ -830,6 +830,7 @@ class DBStructure
 
        /**
         * Loads the database structure definition from the config/dbstructure.php file.
+        * On first pass, defines DB_UPDATE_VERSION constant.
         *
         * @see config/dbstructure.php
         * @return array
index 0b5dfeef46085b5710c924ac8f67b9a579eda358..6a0ed1af205af8312297bc9f0c2ed06495f143e7 100644 (file)
@@ -32,7 +32,7 @@ require_once 'include/dba.php';
  *
  * 1. Create a function "update_4712()" here in the update.php
  * 2. Apply the needed structural changes in config/dbStructure.php
* 3. Set DB_UPDATE_VERSION in boot.php to 4712.
  *
  * If you need to run a script before the database update, name the function "pre_update_4712()"
  */
@@ -32,7 +32,7 @@ require_once 'include/dba.php';
  * 1. Create a function "update_4712()" here in the update.php
  * 2. Apply the needed structural changes in config/dbStructure.php
- * 3. Set DB_UPDATE_VERSION in boot.php to 4712.
+ * 3. Set DB_UPDATE_VERSION in config/dbstructure.php to 4712.
  *
  * If you need to run a script before the database update, name the function "pre_update_4712()"